import framework
# unique to module

class Module(framework.module):

    def __init__(self, params):
        framework.module.__init__(self, params)
        self.register_option('source', 'db', 'yes', 'source of module input')
        self.register_option('verbose', self.goptions['verbose']['value'], 'yes', self.goptions['verbose']['desc'])
        self.info = {
                     'Name': 'Simple Admin Page Finder',
                     'Author': 'scryptz0 @ soldierx.com ',
                     'Description': 'Checks the hosts for possible administrator login pages or directories',
                     'Comments': [
                                  'Source options: [ db | <hostname> | ./path/to/file | query <sql> ]',
                                 ]
                     }

    def do_run(self, params):
        if not self.validate_options(): return
        # === begin here ===
        self.adminlogin_finder()
    
    def adminlogin_finder(self):
        verbose = self.options['verbose']['value']
        
        hosts = self.get_source(self.options['source']['value'], 'SELECT DISTINCT host FROM hosts WHERE host IS NOT NULL ORDER BY host')
        if not hosts: return

        protocols = ['http', 'https']
        # == add known admin directories here ==
        admindirs = [
                     'admin.php', 'login.php', 'admin', 'administrator', 'administrator/index.php', 'mod', 'adminpanel', 'cms',  
                     'admin1.php', 'admin1.html', 'admin2.php', 'admin2.html', 'yonetim.php', 'yonetim.html', 'webmin',
                     'yonetici.php', 'yonetici.html', 'ccms', 'ccms/login.php', 'websvn','maintenance', 'nimda', 'sys.php',  
                     'webmaster', 'adm', 'configuration', 'configure', 'admin/account.php', 'admin/account.html', 'weblog.php'
                     'admin/login.php', 'admin/login.html', 'admin/home.php', 'admin/controlpanel.html', 'cp.php', 'sysmon.php',  
                     'admin/controlpanel.php', 'admin/cp.php', 'admin/cp.html', 'cp.html', 'administrator/login.php', 
                     'administrator/account.html', 'administrator/account.php', 'administrator.php', 'administrator.html', 
                     'login.php', 'login.html', 'modelsearch/login.php', 'moderator.php','moderator.html', 'moderator/login.php', 
                     'moderator/login.html', 'moderator/admin.php', 'moderator/admin.html', 'moderator/', 'account.php', 
                     'account.html', 'controlpanel/', 'controlpanel.php', 'controlpanel.html', 'admincontrol.php', 'manage',  
                     'admincontrol.html', 'adminpanel.php', 'adminpanel.html', 'admin1.asp', 'admin2.asp', 'yonetim.asp',
                     'yonetici.asp', 'admin/account.asp', 'admin/index.asp', 'admin/login.asp', 'admin/home.asp', 'wp-login.php', 
                     'admin/controlpanel.asp', 'admin.asp', 'admin/cp.asp', 'cp.asp','administrator/index.asp', 'log.php'
                     'administrator/login.asp', 'administrator/account.asp', 'administrator.asp', 'login.asp', 'sshadmin', 
                     'modelsearch/login.asp', 'moderator.asp','moderator/login.asp', 'moderator/admin.asp', 'account.asp', 
                     'controlpanel.asp', 'admincontrol.asp', 'adminpanel.asp', 'fileadmin', 'fileadmin.php', 'fileadmin.asp',
                     'fileadmin.html', 'administration', 'administration.php', 'administration.html', 'sysadmin.php', 
                     'sysadmin.html', 'phpmyadmin', 'myadmin', 'sysadmin.asp', 'sysadmin','ur-admin.asp', 'ur-admin.php', 
                     'ur-admin.html', 'ur-admin', 'Server.php', 'Server.html', 'Server.asp', 'Server', 'wp-admin', 'Menu/admin',   
                     'administr8.php', 'administr8.html','administr8', 'administr8.asp', 'webadmin', 'webadmin.php', 'wp-login',  
                     'webadmin.asp', 'webadmin.html', 'administratie', 'admins', 'admins.php', 'admins.asp', 'admins.html',
                     'administrivia', 'Database_Administration', 'WebAdmin', 'useradmin', 'sysadmins', 'admin1', 'adminpro', 
                     'system-administration', 'administrators', 'pgadmin', 'directadmin','staradmin', 'ServerAdministrator', 
                     'SysAdmin', 'administer', 'LiveUser_admin', 'sys-admin', 'typo3', 'panel', 'cpanel', 'cPanel', 'cpanel_file',
                     'platz_login','rcLogin', 'blogindex', 'formslogin', 'autologin', 'support_login', 'meta_login', 'manuallogin',
                     'simpleLogin', 'loginflat', 'utility_login', 'showlogin','memlogin', 'members', 'login-redirect', 'sub-login',
                     'login1', 'dir-login', 'login_db', 'xlogin', 'smblogin', 'customer_login', 'UserLogin', 'login-us',
                     'acct_login', 'admin_area', 'bigadmin', 'project-admins', 'phppgadmin', 'pureadmin', 'sql-admin', 'radmind', 
                     'openvpnadmin', 'wizmysqladmin','vadmind', 'ezsqliteadmin', 'hpwebjetadmin', 'newsadmin', 'server_admin_small', 
                     'Lotus_Domino_admin', 'bbadmin', 'vmailadmin', 'Indy_admin', 'ccp14admin', 'irc-macadmin','banneradmin', 
                     'phpldapadmin', 'macadmin', 'administratoraccounts', 'admin4_account', 'admin4_colon', 'radmind-1', 'Super-admin',
                     'AdminTools','cmsadmin', 'SysAdmin2', 'globes_admin', 'cadmins', 'phpSQLiteAdmin', 'navSiteAdmin', 'logo_sysadmin',
                     'database_administration','power_user', 'system_administration', 'ss_vms_admin_sm', 'adminx', 'server', 
                    ]
        cnt = 0
        for host in hosts:
            for proto in protocols:
                for pages in admindirs:
                    url = '%s://%s/%s' % (proto, host, pages)
                    try:
                        resp = self.request(url, redirect=False)
                        code = resp.status_code
                    except KeyboardInterrupt:
                        print ''
                        return
                    except:
                        code = 'Error'
                    if code == 200:
                        self.alert('%s => %s. Possible Administrator Page!' % (url, code))
                        cnt += 1
                    elif code == 301:
                        self.alert('%s => %s. Possible Redirection to the Admin Page!' % (url, code))
                        cnt += 1	            
                    else:
                        if verbose: self.output('%s => %s' % (url, code))
        self.output('%d Possible Admin pages found' % (cnt))
